@@ -1,4 +1,4 @@
-from .providers import get_provider
+from .providers import get_provider, get_default_adapter
 from .core.roles import *
 from .core.types import *
 from .beacons.eddystone import *
