@@ -4,12 +4,15 @@ from bleson.interfaces.role import Role
 
 
 class Observer(Role):
+    """ Observer """
 
     def __init__(self, adapter : Adapter, on_advertising_data=None):
         self.adapter = adapter
-        self.on_advertising_data = on_advertising_data
+        self.adapter.on_advertising_data = on_advertising_data
 
     def start(self):
+        """ Start the observer """
+
         self.adapter.start_scanning()
 
     def stop(self):
@@ -17,7 +20,7 @@ class Observer(Role):
 
     @property
     def on_advertising_data(self):
-        return self.adapter.on_advtising_data
+        return self.adapter.on_advertising_data
 
     @on_advertising_data.setter
     def on_advertising_data(self, cb):
